package javax.sound.midi;

import com.sun.media.sound.MidiUtils;
import java.util.Vector;

public class Sequence
{
    public static final float PPQ = 0.0f;
    public static final float SMPTE_24 = 24.0f;
    public static final float SMPTE_25 = 25.0f;
    public static final float SMPTE_30DROP = 29.97f;
    public static final float SMPTE_30 = 30.0f;
    protected float divisionType;
    protected int resolution;
    protected Vector<Track> tracks;
    
    public Sequence(float f, int resolution) throws InvalidMidiDataException {
        this.tracks = new Vector();
        if (f == 0.0f) {
            this.divisionType = 0.0f;
        }
        else if (f == 24.0f) {
            this.divisionType = 24.0f;
        }
        else if (f == 25.0f) {
            this.divisionType = 25.0f;
        }
        else if (f == 29.97f) {
            this.divisionType = 29.97f;
        }
        else if (f == 30.0f) {
            this.divisionType = 30.0f;
        }
        else {
            throw new InvalidMidiDataException("Unsupported division type: " + f);
        }
        this.resolution = resolution;
    }
    
    public Sequence(float f, int resolution, int n) throws InvalidMidiDataException {
        this.tracks = new Vector();
        if (f == 0.0f) {
            this.divisionType = 0.0f;
        }
        else if (f == 24.0f) {
            this.divisionType = 24.0f;
        }
        else if (f == 25.0f) {
            this.divisionType = 25.0f;
        }
        else if (f == 29.97f) {
            this.divisionType = 29.97f;
        }
        else if (f == 30.0f) {
            this.divisionType = 30.0f;
        }
        else {
            throw new InvalidMidiDataException("Unsupported division type: " + f);
        }
        this.resolution = resolution;
        for (int i = 0; i < n; ++i) {
            this.tracks.addElement(new Track());
        }
    }
    
    public float getDivisionType() {
        return this.divisionType;
    }
    
    public int getResolution() {
        return this.resolution;
    }
    
    public Track createTrack() {
        Track obj = new Track();
        this.tracks.addElement(obj);
        return obj;
    }
    
    public boolean deleteTrack(Track obj) {
        return this.tracks.removeElement(obj);
    }
    
    public Track[] getTracks() {
        return (Track[])this.tracks.toArray(new Track[0]);
    }
    
    public long getMicrosecondLength() {
        return MidiUtils.tick2microsecond(this, this.getTickLength(), null);
    }
    
    public long getTickLength() {
        long n = 0L;
        synchronized (this.tracks) {
            for (int i = 0; i < this.tracks.size(); ++i) {
                long ticks = ((Track)this.tracks.elementAt(i)).ticks();
                if (ticks > n) {
                    n = ticks;
                }
            }
            return n;
        }
    }
    
    public Patch[] getPatchList() {
        return new Patch[0];
    }
}
